Crate after_drop
source ·Expand description
This will run when is droped
This will run in drop order, that means newest first
features:
- default = [“std”]
- std
use default-features=false if you don’t want to not have std
This will run when is droped
This will run in drop order, that means newest first
use default-features=false if you don’t want to not have std